'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _config = require('config');

var _config2 = _interopRequireDefault(_config);

var _cors = require('cors');

var _cors2 = _interopRequireDefault(_cors);

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _expressFileupload = require('express-fileupload');

var _expressFileupload2 = _interopRequireDefault(_expressFileupload);

var _expressSession = require('express-session');

var _expressSession2 = _interopRequireDefault(_expressSession);

var _uuid = require('uuid');

var _Database = require('./lib/Database.js');

var _Database2 = _interopRequireDefault(_Database);

var _Logger = require('./lib/Logger.js');

var _Logger2 = _interopRequireDefault(_Logger);

var _SessionStore = require('./lib/SessionStore.js');

var _SessionStore2 = _interopRequireDefault(_SessionStore);

var _SSL = require('./lib/SSL.js');

var _SSL2 = _interopRequireDefault(_SSL);

var _index = require('./routes/index.js');

var _index2 = _interopRequireDefault(_index);

var _swaggerUiExpress = require('swagger-ui-express');

var _swaggerUiExpress2 = _interopRequireDefault(_swaggerUiExpress);

var _swagger = require('../swagger.json');

var _swagger2 = _interopRequireDefault(_swagger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Init Express.


// Swagger examples.
var app = (0, _express2.default)();

// Local modules.


app.server = createServer(app);

// Server options.
app.use(_express2.default.json({
  limit: _config2.default.get('server.parser.bodyLimit'),
  type: 'application/vnd.api+json'
}));

app.use((0, _cors2.default)({
  credentials: _config2.default.get('cors.credentials'),
  methods: _config2.default.get('cors.methods'),
  origin: _config2.default.get('cors.origin'),
  optionsSuccessStatus: 200
}));

app.use((0, _expressFileupload2.default)({
  limits: {
    abortOnLimit: _config2.default.get('server.uploads.abortOnLimit'),
    fileSize: _config2.default.get('server.uploads.fileLimit'),
    safeFileNames: _config2.default.get('server.uploads.safeFileNames')
  }
}));

app.use((0, _expressSession2.default)({
  genid: function genid() {
    return (0, _uuid.v4)();
  },
  name: _config2.default.get('session.name'),
  secret: _config2.default.get('session.secret'),
  resave: _config2.default.get('session.resave'),
  cookie: {
    secure: _config2.default.get('session.cookie.secure')
  },
  saveUninitialized: false,
  store: new _SessionStore2.default(_expressSession2.default)
}));

// Enable logging.
switch (process.env.NODE_ENV) {
  case 'production':
  case 'qa':
  case 'staging':
    app.use((0, _Logger2.default)('combined'));
    break;

  case 'test':
    break;

  default:
    app.use((0, _Logger2.default)('dev'));
}

// Init database (if available).
(0, _Database2.default)(function (db) {

  // Enable routes.
  app.use(_config2.default.get('router.prefix'), (0, _index2.default)({ config: _config2.default, db: db }));

  if (process.env.NODE_ENV === undefined) {
    app.use('/api-doc/', _swaggerUiExpress2.default.serve, _swaggerUiExpress2.default.setup(_swagger2.default));
    app.use('/app-doc/', _express2.default.static('doc'));
  }

  // Launch server.
  var serverPort = _config2.default.get('server.port');
  var serverName = _config2.default.get('server.name');

  app.server.listen(serverPort, serverName, function () {
    console.log('Listening to ' + serverName + ' on port ' + serverPort);
  });

  // Handle errors.
  app.server.on('error', function (err) {
    switch (err.code) {
      case 'EACCES':
        console.error('Port requires elevated privileges');
        process.exit(1);
        break;

      case 'EADDRINUSE':
        console.error('Port is already in use');
        process.exit(1);
        break;

      default:
        throw err;
    }
  });
});

/**
 * Returns a new instance of an HTTP server.
 *
 * @param {Function} requestListener
 *
 * @return {Function}
 */
function createServer(requestListener) {
  var sslEnable = _config2.default.get('server.http.ssl.enable');
  var version = _config2.default.get('server.http.version');

  var options = {
    ca: _SSL2.default.ca(),
    cert: _SSL2.default.cert(),
    key: _SSL2.default.key()
  };

  var protocol = 'HTTP/' + version;
  var status = 'server created (' + process.env.NODE_CONFIG_ENV + ')';

  if (version === 2 && sslEnable) {
    console.log(protocol + ' ' + status);

    return require('http2').createSecureServer(options, requestListener);
  }

  if (version === 1) {
    if (sslEnable) {
      console.log(protocol + ' SSL ' + status);

      return require('https').createServer(options, requestListener);
    } else {
      console.log(protocol + ' ' + status);

      return require('http').createServer(requestListener);
    }
  }
}

/**
 * @export default {Express}
 */
exports.default = app;
//# sourceMappingURL=app.js.map