'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _accesscontrol = require('accesscontrol');

var _config = require('config');

var _config2 = _interopRequireDefault(_config);

var _deepCopy = require('deep-copy');

var _deepCopy2 = _interopRequireDefault(_deepCopy);

var _Utils = require('../lib/Utils.js');

var _Utils2 = _interopRequireDefault(_Utils);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Configuration.
var excludePaths = _config2.default.get('router.accessControl.excludePaths');

// Local modules.

var grantsObject = _config2.default.get('router.accessControl.grantsObject');
var rolesByWeight = _config2.default.get('router.accessControl.rolesByWeight');

/**
 * Middleware to manage access based on ABAC (Attribute-Based Access Control).
 *
 * @see https://www.npmjs.com/package/accesscontrol
 *
 * @export default {Function}
 */

// eslint-disable-next-line max-statements

exports.default = function (_ref, res, next) {
  var method = _ref.method,
      path = _ref.path,
      session = _ref.session;

  excludePaths = (0, _deepCopy2.default)(excludePaths);
  grantsObject = (0, _deepCopy2.default)(grantsObject);
  rolesByWeight = (0, _deepCopy2.default)(rolesByWeight);

  // Skip public routes.
  if (_Utils2.default.matches(excludePaths, path)) {
    return next();
  }

  // Check grants/roles exist.
  if (!grantsObject || !rolesByWeight) {
    return next();
  }

  var ac = new _accesscontrol.AccessControl(grantsObject);

  // Grant role access.
  var user = session.role || 'anonymous';

  var userRoles = getUserRoles(rolesByWeight, user);
  var resource = getResource(userRoles, path);

  if (resource && userRoles) {
    userRoles.shift();

    ac.grant(user).extend(userRoles);
  }

  // Check permissions.
  var permission = void 0;

  if (resource) {
    switch (method) {
      case 'POST':
        permission = ac.can(user).createAny(resource);
        break;

      case 'PATCH':
      case 'PUT':
        permission = ac.can(user).updateAny(resource);
        break;

      case 'DELETE':
        permission = ac.can(user).deleteAny(resource);
        break;

      default:
        permission = ac.can(user).readAny(resource);
    }

    if (permission.granted) {
      return next();
    }
  }

  res.status(401).json({});
  res.end();
};

/**
 * Return user roles for a given user.
 *
 * @param {Array} roles
 *   User roles (weighted).
 *
 * @param {String} user
 *   User name.
 *
 * @return {Array}
 */


function getUserRoles(roles, user) {
  return roles.slice(roles.indexOf(user));
}

/**
 * Return ABAC resource for a given path.
 *
 * @param {Array} roles
 *   User roles (weighted).
 *
 * @param {String} path
 *   Route path.
 *
 * @return {String}
 */
function getResource(roles, path) {
  for (var i = 0; i < roles.length; i++) {
    var role = roles[i];

    // Check path for a dynamic segment.
    if (grantsObject[role][path]) {

      // None exists.
      return path;
    }

    var basePath = path.substring(0, path.lastIndexOf('/'));

    // Return the base path, if exists.
    if (grantsObject[role][basePath]) {
      return basePath;
    }
  }
}
//# sourceMappingURL=AccessControlManager.js.map