'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _config = require('config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Middleware to send JSON API supported Content-Type header.
 *
 * @see http://jsonapi.org/format/#content-negotiation-servers
 *
 * @export default {Function}
 */
exports.default = function (req, res, next) {

  // Exclude documentation requests.
  if (process.env.NODE_ENV === undefined && /^\/ap[ip]-doc/.test(req.path)) {
    return next();
  }

  // Skip headers on empty response.
  var send = res.send;
  res.send = function (body) {
    if (_config2.default.get('server.allowEmptyBody') === false || body) {
      res.set('Content-Type', 'application/vnd.api+json');
    }
    send.call(this, body);
  };

  next();
};
//# sourceMappingURL=ContentTypeHeader.js.map