'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _express = require('express');

/**
 * Middleware to handle resource routing responsibilities.
 *
 * Ported from 'resource-router-middleware' to support ID-less routing.
 *
 * @see https://github.com/developit/resource-router-middleware/pull/18
 *
 * Copyright (c) 2015, Jason Miller
 *
 * https://opensource.org/licenses/BSD-3-Clause
 */
var keyed = ['get', 'read', 'put', 'update', 'patch', 'modify', 'del', 'delete'];

var ResourceRouter = function ResourceRouter(route) {
  route.mergeParams = !!route.mergeParams;

  var router = (0, _express.Router)({
    mergeParams: route.mergeParams
  });

  if (route.middleware) {
    router.use(route.middleware);
  }

  if (route.load) {
    router.param(route.id, function (req, res, next, id) {
      route.load(req, id, function (err, data) {
        if (err) {
          return res.status(404).send(err);
        }

        req[route.id] = data;
        next();
      });
    });
  }

  var map = {
    index: 'get',
    list: 'get',
    read: 'get',
    create: 'post',
    update: 'put',
    modify: 'patch'
  };

  for (var key in route) {
    if (route.hasOwnProperty(key)) {
      var fn = map[key] || key;

      if (typeof router[fn] === 'function') {
        var url = ~keyed.indexOf(key) && route.id ? '/:' + route.id : '/';
        router[fn](url, route[key]);
      }
    }
  }

  return router;
};

ResourceRouter.keyed = keyed;

/**
 * @export default {Function}
 */
exports.default = ResourceRouter;
//# sourceMappingURL=ResourceRouter.js.map