'use strict';

// Local modules.

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Random = require('../../lib/Random.js');

var _Random2 = _interopRequireDefault(_Random);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Router resource example.
 *
 * @export default {Function}
 */
exports.default = function (session) {
  return {

    /**
     * Create a new user.
     *
     * @param {Object} props
     *   User properties.
     */
    createUser: function createUser(props) {
      this.initDatabase();

      var user = {
        id: props.id || _Random2.default.guid(),
        name: props.name,
        age: props.age,
        gender: props.gender
      };

      session.user.push(user);

      return user;
    },

    /**
     * Delete a user by ID.
     *
     * @param {String} id
     *   User identifier.
     */
    deleteUser: function deleteUser(id) {
      var index = this.getUsers().indexOf(this.getUser(id));

      session.user.splice(index, 1);
    },

    /**
     * Return an array of users.
     *
     * @return {Array}
     */
    getUsers: function getUsers() {
      this.initDatabase();

      return session.user;
    },

    /**
     * Return a user by ID.
     *
     * @param {String} id
     *   User identifier.
     *
     * @return {Object}
     */
    getUser: function getUser(id) {
      return this.getUsers().find(function (user) {
        return user.id === id;
      });
    },

    /**
     * Update a user by ID.
     *
     * @param {String} id
     *   User identifier.
     *
     * @param {Object} props
     *   User properties.
     */
    updateUser: function updateUser(id, props) {
      var index = this.getUsers().indexOf(this.getUser(id));

      for (var key in props) {
        if (session.user[index].hasOwnProperty(key)) {
          session.user[index][key] = props[key];
        }
      }
    },

    /**
     * Populate the session store with dummy data.
     */
    initDatabase: function initDatabase() {
      if (!session.user) {
        session.user = [{
          id: '00000000-0000-0000-0000-000000000001',
          name: 'Foo Bar',
          age: 10,
          gender: 'Male'
        }, {
          id: '00000000-0000-0000-0000-000000000002',
          name: 'Biz Baz',
          age: 20,
          gender: 'Female'
        }, {
          id: '00000000-0000-0000-0000-000000000003',
          name: 'Qui Qux',
          age: 30,
          gender: 'Binary'
        }];
      }
    }
  };
};
//# sourceMappingURL=User.js.map