'use strict';

// Local modules.

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ResourceRouter = require('../../middleware/ResourceRouter.js');

var _ResourceRouter2 = _interopRequireDefault(_ResourceRouter);

var _User = require('../../resources/examples/User.js');

var _User2 = _interopRequireDefault(_User);

var _User3 = require('../../serializers/examples/User.js');

var _User4 = _interopRequireDefault(_User3);

var _User5 = require('../../validators/examples/User.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @export default
 */
exports.default = function (_ref) {
  var config = _ref.config,
      db = _ref.db;
  return (0, _ResourceRouter2.default)({

    /**
     * Property name to store preloaded user on `request`.
     */
    id: 'user',

    /**
     * Enable validation.
     */
    middleware: _User5.validate,

    /**
     * For requests with an `id`, auto-load the user.
     */
    load: function load(_ref2, id, callback) {
      var session = _ref2.session;

      var user = (0, _User2.default)(session).getUser(id);
      var err = user ? null : {};

      callback(err, user);
    },


    /**
     * List all users.
     *
     * GET /user
     */
    list: function list(_ref3, res) {
      var params = _ref3.params,
          session = _ref3.session;

      var users = (0, _User2.default)(session).getUsers();
      if (users) {
        res.status(200).json(_User4.default.get(users));
      } else {
        res.status(204).send();
      }
    },


    /**
     * Create a new user.
     *
     * POST /user
     */
    create: function create(_ref4, res) {
      var body = _ref4.body,
          session = _ref4.session;

      var user = (0, _User2.default)(session).createUser(body);

      res.status(201).json(_User4.default.get(user));
    },


    /**
     * Return a given user.
     *
     * GET /user/:id
     */
    read: function read(_ref5, res) {
      var user = _ref5.user;

      res.status(200).json(_User4.default.get(user));
    },


    /**
     * Update a given user.
     *
     * PUT /user/:id
     */
    update: function update(_ref6, res) {
      var user = _ref6.user,
          body = _ref6.body,
          session = _ref6.session;

      (0, _User2.default)(session).updateUser(user.id, body);

      res.status(204).send();
    },


    /**
     * Modify a given user.
     *
     * PATCH /user/:id
     */
    modify: function modify(_ref7, res) {
      var user = _ref7.user,
          body = _ref7.body,
          session = _ref7.session;

      (0, _User2.default)(session).updateUser(user.id, body);

      res.status(204).send();
    },


    /**
     * Delete a given user.
     *
     * DELETE /user/:id
     */
    delete: function _delete(_ref8, res) {
      var user = _ref8.user,
          session = _ref8.session;

      (0, _User2.default)(session).deleteUser(user.id);

      res.status(204).send();
    }
  });
};
//# sourceMappingURL=User.js.map