'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validate = exports.schema = undefined;

var _expressValidator = require('express-validator');

var _ValidatorResult = require('../../middleware/ValidatorResult.js');

var _ValidatorResult2 = _interopRequireDefault(_ValidatorResult);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Validator schema.
 *
 * @const {Object} schema
 */
var schema = {
  age: {
    in: ['body'],
    isNumeric: {
      errorMessage: 'Allowed values: Numeric characters'
    },

    // When excludePaths is defined restrict request method
    // for the given parameter.  This is overridden when
    // defined in the ABAC grantsObject
    //
    //custom: {
    //  options: (value, {req}) => {
    //    if (req.method.match(/PATCH|POST|PUT/)) {
    //      return value;
    //    }
    //
    //    return Promise.resolve();
    //  }
    //},

    optional: true
  },

  id: {
    in: ['body', 'params'],
    isUUID: {
      errorMessage: 'Allowed values: UUID version 1, 3, 4, or 5'
    },
    optional: true
  },

  gender: {
    in: ['body'],
    isIn: {
      errorMessage: 'Allowed values: M, F, or undefined',
      options: [['Male', 'Female', 'Binary']]
    },
    optional: true
  },

  name: {
    in: ['body'],
    matches: {
      options: [/^[a-zA-Z\s]+$/],
      errorMessage: 'Allowed values: Alphabet and space characters'
    },
    optional: true
  }
};

/**
 * Exported middleware.
 *
 * @const {Array} validate
 */


// Local modules.
var validate = [(0, _expressValidator.checkSchema)(schema), _ValidatorResult2.default];

/**
 * @export {Object}
 */
exports.schema = schema;
exports.validate = validate;
//# sourceMappingURL=User.js.map